==> webERP4.07.1.zip: webERP4.07.1/includes/LanguagesArray.php <==
<?php
$LanguagesArray = array();

$LanguagesArray['en_US.utf8']['LanguageName'] = _('English US');
$LanguagesArray['en_US.utf8']['WindowsLocale'] = 'english-us';
$LanguagesArray['en_US.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_US.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['en_GB.utf8']['LanguageName'] = _('English British');
$LanguagesArray['en_GB.utf8']['WindowsLocale'] = 'english-uk';
$LanguagesArray['en_GB.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_GB.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['en_IN.utf8']['LanguageName'] = _('English India');
$LanguagesArray['en_IN.utf8']['WindowsLocale'] = 'english-in';
$LanguagesArray['en_IN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_IN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['cz_CZ.utf8']['LanguageName'] = _('Czech');
$LanguagesArray['cz_CZ.utf8']['WindowsLocale'] = 'czech';
$LanguagesArray['cz_CZ.utf8']['DecimalPoint'] = ',';
$LanguagesArray['cz_CZ.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['de_DE.utf8']['LanguageName'] = _('German');
$LanguagesArray['de_DE.utf8']['WindowsLocale'] = 'german';
$LanguagesArray['de_DE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['de_DE.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['el_GR.utf8']['LanguageName'] = _('Greek');
$LanguagesArray['el_GR.utf8']['WindowsLocale'] = 'greek';
$LanguagesArray['el_GR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['el_GR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['es_ES.utf8']['LanguageName'] = _('Spanish');
$LanguagesArray['es_ES.utf8']['WindowsLocale'] = 'spanish';
$LanguagesArray['es_ES.utf8']['DecimalPoint'] = ',';
$LanguagesArray['es_ES.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['et_EE.utf8']['LanguageName'] = _('Estonian');
$LanguagesArray['et_EE.utf8']['WindowsLocale'] = 'estonian';
$LanguagesArray['et_EE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['et_EE.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['fa_IR.utf8']['LanguageName'] = _('Persian');
$LanguagesArray['fa_IR.utf8']['WindowsLocale'] = 'persian';
$LanguagesArray['fa_IR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['fa_IR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['fr_FR.utf8']['LanguageName'] = _('French');
$LanguagesArray['fr_FR.utf8']['WindowsLocale'] = 'french';
$LanguagesArray['fr_FR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['fr_FR.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['hi_IN.utf8']['LanguageName'] = _('Hindi');
$LanguagesArray['hi_IN.utf8']['WindowsLocale'] = 'hindi';
$LanguagesArray['hi_IN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['hi_IN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['hr_HR.utf8']['LanguageName'] = _('Hungarian');
$LanguagesArray['hr_HR.utf8']['WindowsLocale'] = 'hungarian';
$LanguagesArray['hr_HR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['hr_HR.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['id_ID.utf8']['LanguageName'] = _('Indonesian');
$LanguagesArray['id_ID.utf8']['WindowsLocale'] = 'indonesian';
$LanguagesArray['id_ID.utf8']['DecimalPoint'] = ',';
$LanguagesArray['id_ID.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['it_IT.utf8']['LanguageName'] = _('Italian');
$LanguagesArray['it_IT.utf8']['WindowsLocale'] = 'italian';
$LanguagesArray['it_IT.utf8']['DecimalPoint'] = ',';
$LanguagesArray['it_IT.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ja_JP.utf8']['LanguageName'] = _('Japanese');
$LanguagesArray['ja_JP.utf8']['WindowsLocale'] = 'japanese';
$LanguagesArray['ja_JP.utf8']['DecimalPoint'] = '.';
$LanguagesArray['ja_JP.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['lv_LV.utf8']['LanguageName'] = _('Latvian');
$LanguagesArray['lv_LV.utf8']['WindowsLocale'] = 'latvian';
$LanguagesArray['lv_LV.utf8']['DecimalPoint'] = ',';
$LanguagesArray['lv_LV.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['nl_NL.utf8']['LanguageName'] = _('Dutch');
$LanguagesArray['nl_NL.utf8']['WindowsLocale'] = 'dutch';
$LanguagesArray['nl_NL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['nl_NL.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['pl_PL.utf8']['LanguageName'] = _('Polish');
$LanguagesArray['pl_PL.utf8']['WindowsLocale'] = 'polish';
$LanguagesArray['pl_PL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pl_PL.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['pt_BR.utf8']['LanguageName'] = _('Brazilian Portuguese');
$LanguagesArray['pt_BR.utf8']['WindowsLocale'] = 'portuguese-brazil';
$LanguagesArray['pt_BR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pt_BR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['pt_PT.utf8']['LanguageName'] = _('Portuguese');
$LanguagesArray['pt_PT.utf8']['WindowsLocale'] = 'portuguese';
$LanguagesArray['pt_PT.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pt_PT.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ro_RO.utf8']['LanguageName'] = _('Romanian');
$LanguagesArray['ro_RO.utf8']['WindowsLocale'] = 'romanian';
$LanguagesArray['ro_RO.utf8']['DecimalPoint'] = ',';
$LanguagesArray['ro_RO.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ru_RU.utf8']['LanguageName'] = _('Russian');
$LanguagesArray['ru_RU.utf8']['WindowsLocale'] = 'russian';
$LanguagesArray['ru_RU.utf8']['DecimalPoint'] = ',';
$LanguagesArray['ru_RU.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sq_AL.utf8']['LanguageName'] = _('Albanian');
$LanguagesArray['sq_AL.utf8']['WindowsLocale'] = 'albanian';
$LanguagesArray['sq_AL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['sq_AL.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sv_SE.utf8']['LanguageName'] = _('Swedish');
$LanguagesArray['sv_SE.utf8']['WindowsLocale'] = 'swedish';
$LanguagesArray['sv_SE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['sv_SE.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sw_KE.utf8']['LanguageName'] = _('Kiswahili');
$LanguagesArray['sw_KE.utf8']['WindowsLocale'] = 'kiswahili';
$LanguagesArray['sw_KE.utf8']['DecimalPoint'] = '.';
$LanguagesArray['sw_KE.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['tr_TR.utf8']['LanguageName'] = _('Turkish');
$LanguagesArray['tr_TR.utf8']['WindowsLocale'] = 'turkish';
$LanguagesArray['tr_TR.utf8']['DecimalPoint'] = '.';
$LanguagesArray['tr_TR.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['vi_VN.utf8']['LanguageName'] = _('Vietnamese');
$LanguagesArray['vi_VN.utf8']['WindowsLocale'] = 'vietnamese';
$LanguagesArray['vi_VN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['vi_VN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['zh_CN.utf8']['LanguageName'] = _('Chinese - Simplified');
$LanguagesArray['zh_CN.utf8']['WindowsLocale'] = 'chinese-simplified';
$LanguagesArray['zh_CN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['zh_CN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['zh_HK.utf8']['LanguageName'] = _('Chinese - Traditional');
$LanguagesArray['zh_HK.utf8']['WindowsLocale'] = 'chinese-traditional';
$LanguagesArray['zh_HK.utf8']['DecimalPoint'] = '.';
$LanguagesArray['zh_HK.utf8']['ThousandsSeparator'] = ',';

asort($LanguagesArray);
?>

==> webERP4.08.4.zip: webERP4.08.4/includes/LanguagesArray.php <==
<?php
$LanguagesArray = array();

$LanguagesArray['en_US.utf8']['LanguageName'] = _('English US');
$LanguagesArray['en_US.utf8']['WindowsLocale'] = 'english-us';
$LanguagesArray['en_US.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_US.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['en_GB.utf8']['LanguageName'] = _('English British');
$LanguagesArray['en_GB.utf8']['WindowsLocale'] = 'english-uk';
$LanguagesArray['en_GB.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_GB.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['en_IN.utf8']['LanguageName'] = _('English India');
$LanguagesArray['en_IN.utf8']['WindowsLocale'] = 'english-in';
$LanguagesArray['en_IN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['en_IN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['ar_EG.utf8']['LanguageName'] = _('Arabic Eygptian');
$LanguagesArray['ar_EG.utf8']['WindowsLocale'] = 'arabic';
$LanguagesArray['ar_EG.utf8']['DecimalPoint'] = ',';
$LanguagesArray['ar_EG.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['cz_CZ.utf8']['LanguageName'] = _('Czech');
$LanguagesArray['cz_CZ.utf8']['WindowsLocale'] = 'czech';
$LanguagesArray['cz_CZ.utf8']['DecimalPoint'] = ',';
$LanguagesArray['cz_CZ.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['de_DE.utf8']['LanguageName'] = _('German');
$LanguagesArray['de_DE.utf8']['WindowsLocale'] = 'german';
$LanguagesArray['de_DE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['de_DE.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['el_GR.utf8']['LanguageName'] = _('Greek');
$LanguagesArray['el_GR.utf8']['WindowsLocale'] = 'greek';
$LanguagesArray['el_GR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['el_GR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['es_ES.utf8']['LanguageName'] = _('Spanish');
$LanguagesArray['es_ES.utf8']['WindowsLocale'] = 'spanish';
$LanguagesArray['es_ES.utf8']['DecimalPoint'] = ',';
$LanguagesArray['es_ES.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['et_EE.utf8']['LanguageName'] = _('Estonian');
$LanguagesArray['et_EE.utf8']['WindowsLocale'] = 'estonian';
$LanguagesArray['et_EE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['et_EE.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['fa_IR.utf8']['LanguageName'] = _('Persian');
$LanguagesArray['fa_IR.utf8']['WindowsLocale'] = 'persian';
$LanguagesArray['fa_IR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['fa_IR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['fr_FR.utf8']['LanguageName'] = _('French');
$LanguagesArray['fr_FR.utf8']['WindowsLocale'] = 'french';
$LanguagesArray['fr_FR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['fr_FR.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['hi_IN.utf8']['LanguageName'] = _('Hindi');
$LanguagesArray['hi_IN.utf8']['WindowsLocale'] = 'hindi';
$LanguagesArray['hi_IN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['hi_IN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['hr_HR.utf8']['LanguageName'] = _('Hungarian');
$LanguagesArray['hr_HR.utf8']['WindowsLocale'] = 'hungarian';
$LanguagesArray['hr_HR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['hr_HR.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['id_ID.utf8']['LanguageName'] = _('Indonesian');
$LanguagesArray['id_ID.utf8']['WindowsLocale'] = 'indonesian';
$LanguagesArray['id_ID.utf8']['DecimalPoint'] = ',';
$LanguagesArray['id_ID.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['it_IT.utf8']['LanguageName'] = _('Italian');
$LanguagesArray['it_IT.utf8']['WindowsLocale'] = 'italian';
$LanguagesArray['it_IT.utf8']['DecimalPoint'] = ',';
$LanguagesArray['it_IT.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ja_JP.utf8']['LanguageName'] = _('Japanese');
$LanguagesArray['ja_JP.utf8']['WindowsLocale'] = 'japanese';
$LanguagesArray['ja_JP.utf8']['DecimalPoint'] = '.';
$LanguagesArray['ja_JP.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['lv_LV.utf8']['LanguageName'] = _('Latvian');
$LanguagesArray['lv_LV.utf8']['WindowsLocale'] = 'latvian';
$LanguagesArray['lv_LV.utf8']['DecimalPoint'] = ',';
$LanguagesArray['lv_LV.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['nl_NL.utf8']['LanguageName'] = _('Dutch');
$LanguagesArray['nl_NL.utf8']['WindowsLocale'] = 'dutch';
$LanguagesArray['nl_NL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['nl_NL.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['pl_PL.utf8']['LanguageName'] = _('Polish');
$LanguagesArray['pl_PL.utf8']['WindowsLocale'] = 'polish';
$LanguagesArray['pl_PL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pl_PL.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['pt_BR.utf8']['LanguageName'] = _('Brazilian Portuguese');
$LanguagesArray['pt_BR.utf8']['WindowsLocale'] = 'portuguese-brazil';
$LanguagesArray['pt_BR.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pt_BR.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['pt_PT.utf8']['LanguageName'] = _('Portuguese');
$LanguagesArray['pt_PT.utf8']['WindowsLocale'] = 'portuguese';
$LanguagesArray['pt_PT.utf8']['DecimalPoint'] = ',';
$LanguagesArray['pt_PT.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ro_RO.utf8']['LanguageName'] = _('Romanian');
$LanguagesArray['ro_RO.utf8']['WindowsLocale'] = 'romanian';
$LanguagesArray['ro_RO.utf8']['DecimalPoint'] = ',';
$LanguagesArray['ro_RO.utf8']['ThousandsSeparator'] = '.';

$LanguagesArray['ru_RU.utf8']['LanguageName'] = _('Russian');
$LanguagesArray['ru_RU.utf8']['WindowsLocale'] = 'russian';
$LanguagesArray['ru_RU.utf8']['DecimalPoint'] = ',';
$LanguagesArray['ru_RU.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sq_AL.utf8']['LanguageName'] = _('Albanian');
$LanguagesArray['sq_AL.utf8']['WindowsLocale'] = 'albanian';
$LanguagesArray['sq_AL.utf8']['DecimalPoint'] = ',';
$LanguagesArray['sq_AL.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sv_SE.utf8']['LanguageName'] = _('Swedish');
$LanguagesArray['sv_SE.utf8']['WindowsLocale'] = 'swedish';
$LanguagesArray['sv_SE.utf8']['DecimalPoint'] = ',';
$LanguagesArray['sv_SE.utf8']['ThousandsSeparator'] = ' ';

$LanguagesArray['sw_KE.utf8']['LanguageName'] = _('Kiswahili');
$LanguagesArray['sw_KE.utf8']['WindowsLocale'] = 'kiswahili';
$LanguagesArray['sw_KE.utf8']['DecimalPoint'] = '.';
$LanguagesArray['sw_KE.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['tr_TR.utf8']['LanguageName'] = _('Turkish');
$LanguagesArray['tr_TR.utf8']['WindowsLocale'] = 'turkish';
$LanguagesArray['tr_TR.utf8']['DecimalPoint'] = '.';
$LanguagesArray['tr_TR.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['vi_VN.utf8']['LanguageName'] = _('Vietnamese');
$LanguagesArray['vi_VN.utf8']['WindowsLocale'] = 'vietnamese';
$LanguagesArray['vi_VN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['vi_VN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['zh_CN.utf8']['LanguageName'] = _('Chinese - Simplified');
$LanguagesArray['zh_CN.utf8']['WindowsLocale'] = 'chinese-simplified';
$LanguagesArray['zh_CN.utf8']['DecimalPoint'] = '.';
$LanguagesArray['zh_CN.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['zh_HK.utf8']['LanguageName'] = _('Chinese - Traditional Hongkong');
$LanguagesArray['zh_HK.utf8']['WindowsLocale'] = 'chinese-traditional';
$LanguagesArray['zh_HK.utf8']['DecimalPoint'] = '.';
$LanguagesArray['zh_HK.utf8']['ThousandsSeparator'] = ',';

$LanguagesArray['zh_TW.utf8']['LanguageName'] = _('Chinese - Traditional Taiwan');
$LanguagesArray['zh_TW.utf8']['WindowsLocale'] = 'chinese-traditional';
$LanguagesArray['zh_TW.utf8']['DecimalPoint'] = '.';
$LanguagesArray['zh_TW.utf8']['ThousandsSeparator'] = ',';

asort($LanguagesArray);
?>
